@@ -69,7 +69,8 @@ def Gamma_VV(molecule1: Molecule, molecule2: Molecule, T: float, T1_1: float, T1
 def Gamma_22(molecule1: Molecule, molecule2: Molecule, molecule_new1: Molecule, molecule_new2: Molecule, T: float,
              T1_1: float, T1_2: float, T1_new1: float, T1_new2: float, n_molecule1: float, n_molecule2: float,
              n_molecule_new1: float, n_molecule_new2: float, i: int, k: int, i_new: int, k_new: int) -> float:
-    """Calculates the generalized thermodynamic force :math:`\\Gamma^{2\leftrightarrows2}` for a VV transition:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{2\leftrightarrows2}` for a bimolecular
+    exchange reaction:
     M1(i) + M2(k) -> M3(i_new) + M4(k_new)
 
     Parameters
@@ -252,7 +253,8 @@ def raw_Gamma_22(vibr_one1: float, vibr_one2: float, vibr_one_new1: float, vibr_
                  T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: float, n_molecule1: float,
                  n_molecule2: float,  n_molecule_new1: float, n_molecule_new2: float,
                  i: int, k: int, i_new: int, k_new: int) -> float:
-    """Calculates the generalized thermodynamic force :math:`\\Gamma^{2\leftrightarrows2}` for a VV transition:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{2\leftrightarrows2}` for a bimolecular
+    exchange reaction:
     M1(i) + M2(k) -> M3(i_new) + M4(k_new), *raw* version
 
     Parameters
@@ -411,7 +413,7 @@ def raw_find_natom_diss_eq(Z_int: float, mass_molecule: float, mass_atom1: float
     float
         Numeric density of atoms at which chemical equilibrium occurs in the mixture
     """
-    xatom = brentq(raw_Gamma_diss_binary_equilibrium_xatom, 0, 1, xtol=0.00001, maxiter=1000,
+    xatom = brentq(Gamma_diss_binary_equilibrium_xatom, 0, 1, xtol=0.00001, maxiter=1000,
                    args=(Z_int, mass_molecule, mass_atom1, mass_atom2, molecule_diss, T, n))
     if relative is True:
         return xatom
@@ -419,11 +421,11 @@ def raw_find_natom_diss_eq(Z_int: float, mass_molecule: float, mass_atom1: float
         return n * xatom
 
 
-def raw_Gamma_diss_binary_equilibrium_xatom(x_atom: float, Z_int: float,
-                                            mass_molecule: float, mass_atom1: float, mass_atom2: float,
-                                            molecule_diss: float, T: float, n: float) -> float:
+def Gamma_diss_binary_equilibrium_xatom(x_atom: float, Z_int: float, mass_molecule: float,
+                                        mass_atom1: float, mass_atom2: float, molecule_diss: float,
+                                        T: float, n: float) -> float:
     """A helper function, which calculates Gamma_diss (multiplied by the numeric density of the molecules) for a binary
-    mixture (A2, A) in vibrational equilibrium (a one-temperature distribution is used): 2A + A -> 3A, *raw* version
+    mixture (A2, A) in vibrational equilibrium (a one-temperature distribution is used): 2A + A -> 3A
 
     Parameters
     ----------
