@@ -81,8 +81,9 @@ def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarra
 
 
 def load_dissociation_parameters(molecule: MoleculeSTS, partner: Particle) -> np.ndarray:
-    """Loads dissociation model parameters for the reaction molecule + partner -> atom1 + atom2 + partner. Loads
-    parameters for the Arrhenius model, which is considered to be as follows:
+    """Loads dissociation model parameters for Arrhenius model for the reaction
+    molecule + partner -> atom1 + atom2 + partner.
+    The model for the equilibrium reaction rate coefficient is considered to be as follows:
     :math:`k_{diss} = A T^{n}`
 
     Parameters
@@ -96,8 +97,8 @@ def load_dissociation_parameters(molecule: MoleculeSTS, partner: Particle) -> np
     -------
     np.ndarray
         An array, which contains the following quantities:
-        result[0] - Arrhenius n parameter
-        result[1] - Arrhenius A parameter
+        result[0] - Arrhenius model n parameter
+        result[1] - Arrhenius model A parameter
 
     Raises
     ------
