@@ -12,7 +12,7 @@ from .crosssection import raw_diss_integral_rigid_sphere
 from .particles import MoleculeSTS
 
 
-def k_diss_eq(T: float, model_data: np.ndarray, diss_energy: float) -> float:
+def k_diss_eq(T: float, model_data: np.ndarray, molecule_diss: float) -> float:
     """Calculates the equilibrium dissociation rate constant using the Arrhenius model
 
     Parameters
@@ -21,8 +21,8 @@ def k_diss_eq(T: float, model_data: np.ndarray, diss_energy: float) -> float:
         the temperature of the mixture
     model_data : 1-D array-like
         dissociation model data
-    diss_energy : float
-        dissociation energy of the molecule which dissociates
+    molecule_diss : float
+        the dissociation energy of the molecule
 
     Returns
     -------
@@ -30,7 +30,7 @@ def k_diss_eq(T: float, model_data: np.ndarray, diss_energy: float) -> float:
         Equilibrium dissociation rate constant
 
     """
-    return model_data[1] * (T ** model_data[0]) * np.exp(-diss_energy/(constants.k * T))
+    return raw_k_diss_eq(T, model_data[0], model_data[1], molecule_diss)
 
 
 def diss_rate_treanor_marrone(T: float, model_data: np.ndarray, molecule: MoleculeSTS, i: int,
@@ -63,7 +63,7 @@ def diss_rate_treanor_marrone(T: float, model_data: np.ndarray, molecule: Molecu
         Non-equilibrium dissociation rate constant
 
     """
-    return raw_diss_rate_treanor_marrone(T, model_data, molecule.Z_diss(i, T, model), molecule.diss)
+    return raw_diss_rate_treanor_marrone(T, model_data[0], model_data[1], molecule.Z_diss(i, T, model), molecule.diss)
 
 
 def diss_rate_rigid_sphere(T: float, idata: np.ndarray, molecule: MoleculeSTS, i: int,
@@ -96,15 +96,41 @@ def diss_rate_rigid_sphere(T: float, idata: np.ndarray, molecule: MoleculeSTS, i
                                       vl_dependent)
 
 
-def raw_diss_rate_treanor_marrone(T: float, model_data: np.ndarray, Z_diss: float, molecule_diss: float) -> float:
-    """Calculates the non-equilibrium rate constant using the Treanor-Marrone model
+def raw_k_diss_eq(T: float, arrhenius_n: float, arrhenius_A: float, molecule_diss: float) -> float:
+    """Calculates the equilibrium dissociation rate constant using the Arrhenius model, *raw* version
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
-    model_data : 1-D array-like
-        dissociation model data
+    arrhenius_n : float
+        Arrhenius model n parameter
+    arrhenius_A : float
+        Arrhenius model A parameter
+    molecule_diss : float
+        the dissociation energy of the molecule
+
+    Returns
+    -------
+    float
+        Equilibrium dissociation rate constant
+
+    """
+    return arrhenius_A * (T ** arrhenius_n) * np.exp(-molecule_diss / (constants.k * T))
+
+
+def raw_diss_rate_treanor_marrone(T: float, arrhenius_n: float, arrhenius_A: float, Z_diss: float,
+                                  molecule_diss: float) -> float:
+    """Calculates the non-equilibrium rate constant using the Treanor-Marrone model, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    arrhenius_n : float
+        Arrhenius model n parameter
+    arrhenius_A : float
+        Arrhenius model A parameter
     Z_diss : float
         the value of the non-equilibrium factor
     molecule_diss : float
@@ -116,12 +142,12 @@ def raw_diss_rate_treanor_marrone(T: float, model_data: np.ndarray, Z_diss: floa
         Non-equilibrium dissociation rate constant
 
     """
-    return Z_diss * k_diss_eq(T, model_data, molecule_diss)
+    return Z_diss * raw_k_diss_eq(T, arrhenius_n, arrhenius_A, molecule_diss)
 
 
 def raw_diss_rate_rigid_sphere(T: float, sigma: float, mass: float, molecule_vibr: float, molecule_diss: float,
                                center_of_mass: bool=True, vl_dependent: bool=True) -> float:
-    """Calculates the non-equilibrium rate constant using the rigid-sphere crosssection
+    """Calculates the non-equilibrium rate constant using the rigid-sphere crosssection, *raw* version
 
     Parameters
     ----------
